"use strict";
var React = require("react");
var EventEmitter = require("events");
var enzyme_1 = require("enzyme");
var BackgroundPanel_1 = require("../BackgroundPanel");
var TestUtils = require("react-addons-test-utils");
var backgrounds = [
    { name: "black", value: "#000000" },
    { name: "secondary", value: "rgb(123,123,123)" },
    { name: "tertiary", value: "rgba(123,123,123,.5)" },
    { name: "An image", value: "url(http://placehold.it/350x150)" },
];
describe("Background Panel", function () {
    it("should exist", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel}));
        expect(backgroundPanel).toBeDefined;
    });
    it("should have a default background value of transparent", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel}));
        expect(backgroundPanel.state().backgrounds.length).toBe(0);
    });
    it("should show setup instructions if no colors provided", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel}));
        expect(backgroundPanel.html().match(/Setup Instructions/gmi).length).toBeGreaterThan(0);
    });
    it("should pass the event from swatch clicks through the provided channel", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel}));
        SpiedChannel.emit("background-set", backgrounds);
        var spy = jest.fn();
        SpiedChannel.on("background", spy);
        TestUtils.Simulate.click(TestUtils.scryRenderedDOMComponentsWithTag(backgroundPanel, "h4")[0]);
        expect(spy).toBeCalledWith(backgrounds[0].value);
    });
});
//# sourceMappingURL=BackgroundPanel.js.map